# WRES Explorer
Utilities to visualize and explore output from the [NOAA Office of Water Prediction](https://github.com/NOAA-OWP)'s (OWP) [Water Resources Evaluation Service](https://github.com/NOAA-OWP/wres) (WRES).

## Usage
```console
Usage: wres-explorer [OPTIONS]

  Visualize and explore metrics output from WRES CSV2 formatted output.

  Run "wres-explorer" from the command-line, ctrl+c to stop the server.:

Options:
  --help  Show this message and exit.
```
